import {
  select,
  csv,
  scaleLinear,
  max,
  scalePoint,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const titleText = 'Top 10 Most Populous Countries';
const xAxisLabelText = 'Population';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
 const population = d => d.population;
 const country = d => d.country;
  
 const innerWidth = width - 200; 
 const innerHeight = height - 40;
 
 const xScale = scaleLinear()
  .domain([0, max(data, population)])
  .range([0, innerWidth]);
  
 const xAxis = axisBottom(xScale);
 svg.append('g').call(xAxis)
   .attr('transform', 'translate(40, 450)');
 
 const yScale = scalePoint()
  .domain(data.map(country))
  .range([0, innerHeight])
  .padding(0.6)
 
 const yAxis = axisLeft(yScale).tickSize(-400);
 svg.append('g').call(yAxis)
   .attr('transform', 'translate(200, 0)')
   .selectAll('.domain')
   .remove()
 
 svg.selectAll('circle')
  .data(data)
  .enter()
  .append('circle')
    .attr('cx', d => xScale(population(d)))
    .attr('cy', d => yScale(country(d)))
    .attr('r', 10);
 
};

csv('data.csv').then(data => {
  data.forEach(d => {
    d.population = +d.population * 1000;
  });
  render(data);
});